Ex()
----

.. automethod:: protowhat.sct_syntax.Ex.__call__

AST checks
----------

.. automodule:: protowhat.checks.check_funcs
    :members:

Logic
-------

.. automodule:: protowhat.checks.check_logic
    :members:

Simple checks
-------------

.. automodule:: protowhat.checks.check_simple
    :members:

File checks
-----------

.. automodule:: protowhat.checks.check_files
    :members:

Bash history checks
-------------------

.. automodule:: protowhat.checks.check_bash_history
    :members:
